@@ -3,7 +3,6 @@ module Console.All(action) where
 
 import CmdLine.All
 import Recipe.All
-import Recipe.General
 import Recipe.Haddock
 import Console.Log
 import Console.Search
@@ -12,7 +11,9 @@ import Console.Rank
 import General.Base
 import General.System
 import General.Web
+import System.FilePath
 import Hoogle
+import Hoogle.Type.All
 
 
 action :: CmdLine -> IO ()
@@ -29,10 +30,9 @@ action x@Search{queryParsed = Left err} =
 action (Test files _) = do
     testPrepare
     fails <- fmap sum $ mapM (testFile action) files
-    putStrLn $
-      if fails == 0
-        then "Tests passed"
-        else "TEST FAILURES (" ++ show fails ++ ")"
+    if fails == 0 then putStrLn "Tests passed" else do
+        putStrLn $ "TEST FAILURES (" ++ show fails ++ ")"
+        exitFailure
 
 action (Rank file) = rank file
 
@@ -40,11 +40,11 @@ action x@Data{} = recipes x
 
 action (Log files) = logFiles files
 
-action (Convert from to doc merge haddock) = do
+action (Convert url from to doc merge haddock) = do
     when (any isUpper $ takeBaseName to) $ putStrLn $ "Warning: Hoogle databases should be all lower case, " ++ takeBaseName to
     putStrLn $ "Converting " ++ from
     src <- readFileUtf8 from
-    convert merge (takeBaseName from) to $ unlines $ addLocalDoc doc (lines src)
+    convert url merge (takeBaseName from) to $ unlines $ addLocalDoc doc (lines src)
     where
       addLocalDoc :: Maybe FilePath -> [String] -> [String]
       addLocalDoc doc = if haddock
@@ -62,8 +62,7 @@ action (Convert from to doc merge haddock) = do
 
 action (Combine from to) = do
     putStrLn $ "Combining " ++ show (length from) ++ " databases"
-    xs <- mapM loadDatabase from
-    saveDatabase to $ mconcat xs
+    mergeDatabase from to
 
 action (Dump file sections) = do
     d <- loadDatabase file
@@ -76,3 +75,14 @@ action q@Search{} | fromRight (queryParsed q) == mempty =
 
 action q@Search{} = actionSearch q (fromRight $ queryParsed q)
 
+
+--- convert a single database
+convert :: HackageURL -> [FilePath] -> String -> FilePath -> String -> IO ()
+convert url deps x out src = do
+    deps2 <- filterM doesFileExist deps
+    when (deps /= deps2) $ putStrLn $ "Warning: " ++ x ++ " doesn't know about dependencies on " ++ unwords (deps \\ deps2)
+    dbs <- mapM loadDatabase deps2
+    putStr $ "Converting " ++ x ++ "... "
+    err <- createDatabase url Haskell dbs src out
+    putStrLn "done"
+    unless (null err) $ putStrLn $ "Skipped " ++ show (length err) ++ " warnings in " ++ x
