@@ -1,8 +1,8 @@
 {-# LANGUAGE ScopedTypeVariables #-}
 
 module Hoogle.Store.All(
-    SPut, SGet, runSPut, runSGet,
-    Once, fromOnce, once, getDefer, putDefer,
+    SPut, SGet, runSPut, runSGet, runSGetAt, runAfter,
+    Once, fromOnce, once, findOnce, unsafeFmapOnce, getDefer, putDefer,
     module Hoogle.Store.All
     ) where
 
