@@ -4,10 +4,12 @@ module Test.All(test) where
 import Test.Parse_TypeSig
 import Test.Parse_Query
 import Test.Docs
+import Test.BWT_FM
 
 
 test :: IO ()
-test = print $ do
+test = do
     parse_TypeSig
     parse_Query
     docs
+    bwt_fm
